# gwutil.py - a few utility functions

from subprocess import Popen
from math import log
from time import sleep

from gwlogging import gw_stdout, gw_stderr
from gwcommands import POWEROFF, SYNC
from iceCape import GPS
import gps


from gwfetchutils import *
from gwfileutils import *
from gwtimeutils import *
#TODO remove these imports

def mask2number(mask):
    """Returns the number of a sensor ID as opposed to the mask
            for example 128 -> 7
    """
    return int(log(mask, 2))


def fs_sync():
    # Sync the filesystem before we power off...
    p = Popen(args="%s" % SYNC, shell=True,
        stdout=gw_stdout, stderr=gw_stderr)
    p.wait()


def poweroff(gum, testing):
    if not testing:
        gum.power_off_gumstix(15)
        fs_sync()
        p = Popen(args="%s" % POWEROFF,
            shell=True, stdout=gw_stdout, stderr=gw_stderr)
        p.wait()
    else:
        logger.warn("Testing not powering off")
        exit(0)


def int2bin(n, count=16):
    """returns the binary of integer n, using count number of digits"""
    #http://www.daniweb.com/software-development/python/code/216539/
    #decimal-to-binary-conversion-python
    return "".join([str((n >> y) & 1) for y in range(count - 1, -1, -1)])


def format_status(b):
    s = "|"
    for c in b:
        if c == "1":
            s += " On  |"
        else:
            s += " Off |"
    return s


def recover_time(gum, last_run_time):
    logger.debug("Seeing if MSP time is ok")
    dt = gum.get_datetime()
    if dt > last_run_time:
        logger.info("Time on MSP ok")
        set_system_time(dt)
        return True
    else:
        logger.error("Assuming the MSP lost power, resetting" +
               " to state 0 for safety.")
        gum.turn_on_sensor_output(GPS)
        rc = gps.set_system_time()
        gum.turn_off_sensor_output(GPS)
        if rc == 0:
            #success
            gum.setdatetime()
            set_hwclock()
            return True
        else:
            #failure:
            return False

def handle_power_off(ic, start_time=0, testing=False):
    # While the stayawake file exists,
    # inhibit going into the power off
    # procedure when not in testing mode.
    while stay_awake(start_time):
        logger.warning("Staying awake because of stay awake file or min time")
        sleep(10)

    fs_sync()
    logger.info("Power off")
    # power off
    poweroff(ic, testing)
