#!/usr/bin/env python

from datetime import datetime
from sys import argv
from gwtimeutils import read_hwclock
from gwutil import format_status, int2bin
import iceCape
from gwlogging import logger, WARN
from conversions import conversions 
from variables import BASE, REF, CAM, FARM
import MspJob

__mode__ = None

for arg in argv[1:]:
    if arg == '-B':
        logger.info("Base mode activated")
        __mode__ = BASE
    elif arg == '-R':
        logger.info("Ref mode activated")
        __mode__ = REF
    elif arg == '-C':
        logger.info("Cam mode activated")
        __mode__ = CAM
        __camera__ = True
        __comms__ = False
    elif arg == '-F':
        logger.info("farm mode activated")
        __mode__ = FARM
    else:
        print "Useage: %s  -[B|R|F|C]" % (argv[0])
        print "\t-C: Camera only mode"
        print "\t-B: Base station mode - enables probes"
        print "\t-R: Reference station mode - disables probes"
        print ("\t-F: Farm station mode - only does comms stuff does not" +
                        " do any power management")
        exit(2)

if __mode__ is None:
    logger.critical("Must set a mode")
    exit(1)


ic = iceCape.iceCape()
logger.setLevel(WARN)
print """Glacsweb Status Report
--------------------------------------------------------------------------------
Time Report
------------------------------------------------------------"""
print "System time:\t" + str(datetime.utcnow())
print "Hwclock:\t" + str(read_hwclock())
print "MSP clock:\t" + str(ic.get_epoch())

print """------------------------------------------------------------
Job Report
------------------------------------------------------------"""
no_jobs = ic.read_number_of_jobs()
print "Number of jobs:\t" + str(no_jobs)

if no_jobs > 0:
    jobs = ic.read_job_table()
    for j in jobs:
        if (int(j.jobType) == MspJob.J_P_Gumstix
            or int(j.jobType) == MspJob.J_P_GumstixPcon):
            print "Next Beagle wake:\t" + str(j.exec_time)
            break
    for j in jobs:
        if (int(j.jobType) == MspJob.J_P_GumstixPCON_OFF
                or int(j.jobType) == MspJob.J_P_Gumstix_OFF):
            print "Next Beagle Off:\t" + str(j.exec_time)
            break

    n = datetime(2038, 12, 31)
    # should be far enough in the future for now...

    for j in jobs:
        if j.exec_time < n:
            n = j.exec_time
    print "Next job: \t\t" + str(n)

print """------------------------------------------------------------
Data Report
------------------------------------------------------------"""
print "Number of readings:\t" + str(ic.read_data_amount())

print """------------------------------------------------------------
Output Report
------------------------------------------------------------
12 Volt
--------------------------------------------------
|  0  |  1  |  2  |  3  |  4  |  5  |  6  |  7  |"""
output_status = ic.output_status()
print format_status(int2bin(output_status)[0:8][::-1])
print """--------------------------------------------------
Other
--------------------------------------------------
| 5V0 | 5V1 | 5V2 | 5V4 | 5VA | 5VB | BAT | SEN |"""
print format_status(int2bin(output_status)[8:16][::-1])

print """--------------------------------------------------
Debug
--------------------------------------------------
|  D1 |  D2 |  D3 |"""
debug_status = ic.debug_status()
print format_status(int2bin(debug_status, 3))
print """--------------------------------------------------
Beagle
--------------------------------------------------"""
if ic.bone_status():
    print "On"
else:
    print "Off"
print """--------------------------------------------------
Sensors
--------------------------------------------------"""
ic.output_on(iceCape.BATT_EN)
raw = ic.read_sensors(iceCape.BATT_V)
conv = conversions(__mode__)
print "Battery Voltage:%f" % conv.batV(raw)
print """--------------------------------------------------
|  0  |  1  |  2  |  3  |  4  |  5  |  6  |  7  |"""

ic.output_on(iceCape.SENSE_EN)
output = "|"
for s in [1,2,4,8,16,32,64,128]:
	output += str(ic.read_sensors(s)).ljust(5) + "|"
print output
print """--------------------------------------------------
|  8  |  9  | 10  | 11  | 12  | 13  | 14  | 15  |"""
output = "|"
for s in [256, 512, 1024, 2048, 4096, 8192, 16384, 32768]:
        output += str(ic.read_sensors(s)).ljust(5) + "|"
print output
print"""--------------------------------------------------------------------------------"""
ic.output_off(iceCape.BATT_EN)
ic.output_off(iceCape.SENSE_EN)
ic.output_off(iceCape.BATT_EN)
